@@ -1,3 +1,4 @@
+from copy import deepcopy
 from pprint import pprint
 import tensorflow.keras as keras
 from . import load
@@ -44,18 +45,28 @@ class Model(keras.Model):
     def set_classifier(self,
             nb_classes,
             config,
+            classifier_names=None,
             group_maps=None,
             group_nb_classes=None,
             file_name='classifier',
             folder=load.TFBOX,
             from_logits=None):
         if nb_classes:
-            self.classifier=self._get_classifier(
-                nb_classes,
-                config,
-                file_name=file_name,
-                folder=folder,
-                from_logits=from_logits)
+            if not isinstance(nb_classes,list):
+                nb_classes=[nb_classes]
+            if not classifier_names:
+                classifier_names=[None]*len(nb_classes)
+            self.classifier=[]
+            for n,cname in zip(nb_classes,classifier_names):
+                self.classifier.append(
+                    self._get_classifier(
+                        n,
+                        config,
+                        classifier_name=cname,
+                        file_name=file_name,
+                        folder=folder,
+                        from_logits=from_logits))
+
         if group_maps:
             self.grouping=addons.Groups(group_maps)
             self.group_classifier=self._get_classifier(
@@ -70,12 +81,12 @@ class Model(keras.Model):
 
     def output(self,x):
         if self.classifier:
-            x=self.classifier(x)
+            x=[c(x) for c in self.classifier]
             if self.grouping:
                 gx=self.grouping(x)
                 if self.group_classifier:
                     gx=self.group_classifier(gx)
-                x=[x, gx]
+                x=+[gx]
         return x
 
 
@@ -89,10 +100,13 @@ class Model(keras.Model):
     def _get_classifier(self,
             nb_classes,
             config,
+            classifier_name=None,
             file_name='classifier',
             folder=load.TFBOX,
             from_logits=None):
         if config:
+            config=deepcopy(config)
+            config['name']=classifier_name or config.get('name')
             if from_logits in [True,False]:
                 config=self._update_activation(config,from_logits)
             if nb_classes and config:
