@@ -173,6 +173,12 @@ def match_layer(
     return match
     
 
+def _process_index(index,length):
+    index=int(index)
+    if index<0:
+        index=length+index
+    return index
+
 def set_trainable(
         model,
         matches=[],
@@ -187,7 +193,8 @@ def set_trainable(
         indices=_as_list(indices)
         searches=_as_list(searches)
         excludes=_as_list(excludes)
-        indices=[int(i) for i in indices]
+        nb_layers=len(model.layers)
+        indices=[_process_index(i,nb_layers) for i in indices]
         if return_matched:
             matched=[]
         for i,l in enumerate(model.layers):
